==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/clusterplacementgroups/responses/ListClusterPlacementGroupsResponse.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.clusterplacementgroups.responses;

import com.oracle.bmc.clusterplacementgroups.model.*;

@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20230801")
public class ListClusterPlacementGroupsResponse extends com.oracle.bmc.responses.BmcResponse {
    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    private String opcRequestId;

    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     *
     * @return the value
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * For pagination of a list of items. When paging through a list, if this header appears in the
     * response, then there are additional items to get. Include this value as the {@code page}
     * parameter for the subsequent GET request to get the next batch of items. For information
     * about pagination, see [List
     * Pagination](https://docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm#nine).
     */
    private String opcNextPage;

    /**
     * For pagination of a list of items. When paging through a list, if this header appears in the
     * response, then there are additional items to get. Include this value as the {@code page}
     * parameter for the subsequent GET request to get the next batch of items. For information
     * about pagination, see [List
     * Pagination](https://docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm#nine).
     *
     * @return the value
     */
    public String getOpcNextPage() {
        return opcNextPage;
    }

    /** The returned {@code ClusterPlacementGroupCollection} instance. */
    private com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
            clusterPlacementGroupCollection;

    /**
     * The returned {@code ClusterPlacementGroupCollection} instance.
     *
     * @return the value
     */
    public com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
            getClusterPlacementGroupCollection() {
        return clusterPlacementGroupCollection;
    }

    @java.beans.ConstructorProperties({
        "__httpStatusCode__",
        "headers",
        "opcRequestId",
        "opcNextPage",
        "clusterPlacementGroupCollection"
    })
    private ListClusterPlacementGroupsResponse(
            int __httpStatusCode__,
            java.util.Map<String, java.util.List<String>> headers,
            String opcRequestId,
            String opcNextPage,
            com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                    clusterPlacementGroupCollection) {
        super(__httpStatusCode__, headers);
        this.opcRequestId = opcRequestId;
        this.opcNextPage = opcNextPage;
        this.clusterPlacementGroupCollection = clusterPlacementGroupCollection;
    }

    public static class Builder
            implements com.oracle.bmc.responses.BmcResponse.Builder<
                    ListClusterPlacementGroupsResponse> {
        private int __httpStatusCode__;

        @Override
        public Builder __httpStatusCode__(int __httpStatusCode__) {
            this.__httpStatusCode__ = __httpStatusCode__;
            return this;
        }

        private java.util.Map<String, java.util.List<String>> headers;

        @Override
        public Builder headers(java.util.Map<String, java.util.List<String>> headers) {
            this.headers = headers;
            return this;
        }

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         */
        private String opcRequestId;

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * For pagination of a list of items. When paging through a list, if this header appears in
         * the response, then there are additional items to get. Include this value as the {@code
         * page} parameter for the subsequent GET request to get the next batch of items. For
         * information about pagination, see [List
         * Pagination](https://docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm#nine).
         */
        private String opcNextPage;

        /**
         * For pagination of a list of items. When paging through a list, if this header appears in
         * the response, then there are additional items to get. Include this value as the {@code
         * page} parameter for the subsequent GET request to get the next batch of items. For
         * information about pagination, see [List
         * Pagination](https://docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm#nine).
         *
         * @param opcNextPage the value to set
         * @return this builder
         */
        public Builder opcNextPage(String opcNextPage) {
            this.opcNextPage = opcNextPage;
            return this;
        }

        /** The returned {@code ClusterPlacementGroupCollection} instance. */
        private com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                clusterPlacementGroupCollection;

        /**
         * The returned {@code ClusterPlacementGroupCollection} instance.
         *
         * @param clusterPlacementGroupCollection the value to set
         * @return this builder
         */
        public Builder clusterPlacementGroupCollection(
                com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                        clusterPlacementGroupCollection) {
            this.clusterPlacementGroupCollection = clusterPlacementGroupCollection;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        @Override
        public Builder copy(ListClusterPlacementGroupsResponse o) {
            __httpStatusCode__(o.get__httpStatusCode__());
            headers(o.getHeaders());
            opcRequestId(o.getOpcRequestId());
            opcNextPage(o.getOpcNextPage());
            clusterPlacementGroupCollection(o.getClusterPlacementGroupCollection());

            return this;
        }

        /**
         * Build the response object.
         *
         * @return the response object
         */
        @Override
        public ListClusterPlacementGroupsResponse build() {
            return new ListClusterPlacementGroupsResponse(
                    __httpStatusCode__,
                    headers,
                    opcRequestId,
                    opcNextPage,
                    clusterPlacementGroupCollection);
        }
    }

    /**
     * Return a new builder for this response object.
     *
     * @return builder for the response object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",opcRequestId=").append(String.valueOf(opcRequestId));
        sb.append(",opcNextPage=").append(String.valueOf(opcNextPage));
        sb.append(",clusterPlacementGroupCollection=")
                .append(String.valueOf(clusterPlacementGroupCollection));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof ListClusterPlacementGroupsResponse)) {
            return false;
        }

        ListClusterPlacementGroupsResponse other = (ListClusterPlacementGroupsResponse) o;
        return super.equals(o)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId)
                && java.util.Objects.equals(this.opcNextPage, other.opcNextPage)
                && java.util.Objects.equals(
                        this.clusterPlacementGroupCollection,
                        other.clusterPlacementGroupCollection);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        result = (result * PRIME) + (this.opcNextPage == null ? 43 : this.opcNextPage.hashCode());
        result =
                (result * PRIME)
                        + (this.clusterPlacementGroupCollection == null
                                ? 43
                                : this.clusterPlacementGroupCollection.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/clusterplacementgroups/responses/ListClusterPlacementGroupsResponse.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.clusterplacementgroups.responses;

import com.oracle.bmc.clusterplacementgroups.model.*;

@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20230801")
public class ListClusterPlacementGroupsResponse extends com.oracle.bmc.responses.BmcResponse {
    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    private String opcRequestId;

    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     *
     * @return the value
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * For pagination of a list of items. When paging through a list, if this header appears in the
     * response, then there are additional items to get. Include this value as the {@code page}
     * parameter for the subsequent GET request to get the next batch of items. For information
     * about pagination, see [List
     * Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
     */
    private String opcNextPage;

    /**
     * For pagination of a list of items. When paging through a list, if this header appears in the
     * response, then there are additional items to get. Include this value as the {@code page}
     * parameter for the subsequent GET request to get the next batch of items. For information
     * about pagination, see [List
     * Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
     *
     * @return the value
     */
    public String getOpcNextPage() {
        return opcNextPage;
    }

    /** The returned {@code ClusterPlacementGroupCollection} instance. */
    private com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
            clusterPlacementGroupCollection;

    /**
     * The returned {@code ClusterPlacementGroupCollection} instance.
     *
     * @return the value
     */
    public com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
            getClusterPlacementGroupCollection() {
        return clusterPlacementGroupCollection;
    }

    @java.beans.ConstructorProperties({
        "__httpStatusCode__",
        "headers",
        "opcRequestId",
        "opcNextPage",
        "clusterPlacementGroupCollection"
    })
    private ListClusterPlacementGroupsResponse(
            int __httpStatusCode__,
            java.util.Map<String, java.util.List<String>> headers,
            String opcRequestId,
            String opcNextPage,
            com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                    clusterPlacementGroupCollection) {
        super(__httpStatusCode__, headers);
        this.opcRequestId = opcRequestId;
        this.opcNextPage = opcNextPage;
        this.clusterPlacementGroupCollection = clusterPlacementGroupCollection;
    }

    public static class Builder
            implements com.oracle.bmc.responses.BmcResponse.Builder<
                    ListClusterPlacementGroupsResponse> {
        private int __httpStatusCode__;

        @Override
        public Builder __httpStatusCode__(int __httpStatusCode__) {
            this.__httpStatusCode__ = __httpStatusCode__;
            return this;
        }

        private java.util.Map<String, java.util.List<String>> headers;

        @Override
        public Builder headers(java.util.Map<String, java.util.List<String>> headers) {
            this.headers = headers;
            return this;
        }

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         */
        private String opcRequestId;

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * For pagination of a list of items. When paging through a list, if this header appears in
         * the response, then there are additional items to get. Include this value as the {@code
         * page} parameter for the subsequent GET request to get the next batch of items. For
         * information about pagination, see [List
         * Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
         */
        private String opcNextPage;

        /**
         * For pagination of a list of items. When paging through a list, if this header appears in
         * the response, then there are additional items to get. Include this value as the {@code
         * page} parameter for the subsequent GET request to get the next batch of items. For
         * information about pagination, see [List
         * Pagination](https://docs.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine).
         *
         * @param opcNextPage the value to set
         * @return this builder
         */
        public Builder opcNextPage(String opcNextPage) {
            this.opcNextPage = opcNextPage;
            return this;
        }

        /** The returned {@code ClusterPlacementGroupCollection} instance. */
        private com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                clusterPlacementGroupCollection;

        /**
         * The returned {@code ClusterPlacementGroupCollection} instance.
         *
         * @param clusterPlacementGroupCollection the value to set
         * @return this builder
         */
        public Builder clusterPlacementGroupCollection(
                com.oracle.bmc.clusterplacementgroups.model.ClusterPlacementGroupCollection
                        clusterPlacementGroupCollection) {
            this.clusterPlacementGroupCollection = clusterPlacementGroupCollection;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        @Override
        public Builder copy(ListClusterPlacementGroupsResponse o) {
            __httpStatusCode__(o.get__httpStatusCode__());
            headers(o.getHeaders());
            opcRequestId(o.getOpcRequestId());
            opcNextPage(o.getOpcNextPage());
            clusterPlacementGroupCollection(o.getClusterPlacementGroupCollection());

            return this;
        }

        /**
         * Build the response object.
         *
         * @return the response object
         */
        @Override
        public ListClusterPlacementGroupsResponse build() {
            return new ListClusterPlacementGroupsResponse(
                    __httpStatusCode__,
                    headers,
                    opcRequestId,
                    opcNextPage,
                    clusterPlacementGroupCollection);
        }
    }

    /**
     * Return a new builder for this response object.
     *
     * @return builder for the response object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",opcRequestId=").append(String.valueOf(opcRequestId));
        sb.append(",opcNextPage=").append(String.valueOf(opcNextPage));
        sb.append(",clusterPlacementGroupCollection=")
                .append(String.valueOf(clusterPlacementGroupCollection));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof ListClusterPlacementGroupsResponse)) {
            return false;
        }

        ListClusterPlacementGroupsResponse other = (ListClusterPlacementGroupsResponse) o;
        return super.equals(o)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId)
                && java.util.Objects.equals(this.opcNextPage, other.opcNextPage)
                && java.util.Objects.equals(
                        this.clusterPlacementGroupCollection,
                        other.clusterPlacementGroupCollection);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        result = (result * PRIME) + (this.opcNextPage == null ? 43 : this.opcNextPage.hashCode());
        result =
                (result * PRIME)
                        + (this.clusterPlacementGroupCollection == null
                                ? 43
                                : this.clusterPlacementGroupCollection.hashCode());
        return result;
    }
}
